@@ -1,4 +1,4 @@
-/* Copyright (c) 2017, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2017, 2025, Oracle and/or its affiliates.
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License, version 2.0,
@@ -147,7 +147,7 @@ DEFINE_METHOD(log_service_error, log_service_imp::parse_log_line,
   if (j_code > 0)
     err_code_num = j_code;
   else if (j_sym != nullptr) {
-    std::string error_symbol_with_terminator(j_sym, j_sym_len);
+    const std::string error_symbol_with_terminator(j_sym, j_sym_len);
     err_code_num =
         log_bi->errcode_by_errsymbol(error_symbol_with_terminator.c_str());
   }
@@ -260,7 +260,7 @@ DEFINE_METHOD(int, log_service_imp::run, (void *instance, log_line *ll)) {
                 esc_buff[esc_len++] = '\\';
                 esc_buff[esc_len++] = *(inp_readpos++);
               } else if (((unsigned char)*inp_readpos) <= 0x1f) {
-                size_t esc_have = sizeof(esc_buff) - esc_len - 1;
+                const size_t esc_have = sizeof(esc_buff) - esc_len - 1;
                 size_t esc_want;
                 esc_want = log_bs->substitute(
                     &esc_buff[esc_len], esc_have, "\\u%04x",
