@@ -1,15 +1,16 @@
-/* Copyright (c) 2000, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2000, 2025, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -146,9 +147,10 @@ struct MEM_ROOT;
 
 #define MYF_RW MYF(MY_WME + MY_NABP) /* For my_read & my_write */
 
-#define MY_CHECK_ERROR 1    /* Params to my_end; Check open-close */
-#define MY_GIVE_INFO 2      /* Give time info about process*/
-#define MY_DONT_FREE_DBUG 4 /* Do not call DBUG_END() in my_end() */
+#define MY_CHECK_ERROR 1        /* Params to my_end; Check open-close */
+#define MY_GIVE_INFO 2          /* Give time info about process*/
+#define MY_DONT_FREE_DBUG 4     /* Do not call DBUG_END() in my_end() */
+#define MY_END_PROXY_MAIN_THD 8 /* Free resources for main thread */
 
 /* Flags for my_error() */
 #define ME_BELL 4          /* DEPRECATED: Ring bell then printing message */
@@ -975,6 +977,13 @@ extern MYSQL_PLUGIN_IMPORT PSI_tls_channel_bootstrap *psi_tls_channel_hook;
 extern void set_psi_tls_channel_service(void *psi);
 #endif /* HAVE_PSI_INTERFACE */
 
+/* Total physical memory available */
+[[nodiscard]] extern unsigned long long my_physical_memory();
+
+/* Compares versions and determine if clone is allowed */
+[[nodiscard]] extern bool are_versions_clone_compatible(std::string ver1,
+                                                        std::string ver2);
+
 /**
   @} (end of group MYSYS)
 */
