@@ -1,4 +1,4 @@
-/* Copyright (c) 2014, 2024, Oracle and/or its affiliates.
+/* Copyright (c) 2014, 2025, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
@@ -612,6 +612,8 @@ end:
         "Fatal error during execution on the Applier module of Group "
         "Replication.";
     leave_group_on_failure::mask leave_actions;
+    if (applier_thd->killed)
+      LogPluginErr(ERROR_LEVEL, ER_GRP_RPL_APPLIER_THD_KILLED_BY_SQL_KILL);
     /*
       Only follow exit_state_action if we were already inside a group. We may
       happen to come across an applier error during the startup of GR (i.e.
