@@ -1,15 +1,16 @@
-/* Copyright (c) 2015, 2023, Oracle and/or its affiliates.
+/* Copyright (c) 2015, 2025, Oracle and/or its affiliates.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2.0,
    as published by the Free Software Foundation.
 
-   This program is also distributed with certain software (including
+   This program is designed to work with certain software (including
    but not limited to OpenSSL) that is licensed under separate terms,
    as designated in a particular file or component or in included license
    documentation.  The authors of MySQL hereby grant you an additional
    permission to link the program and your derivative works with the
-   separately licensed software that they have included with MySQL.
+   separately licensed software that they have either included with
+   the program or referenced in the documentation.
 
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -76,6 +77,7 @@ PSI_memory_key key_memory_rpl_thd_context;
 PSI_memory_key key_memory_applier;
 PSI_memory_key key_memory_recovery;
 PSI_memory_key key_memory_show_binlog_events;
+PSI_memory_key key_memory_relaylog_recovery;
 PSI_memory_key key_memory_REPLICA_INFO;
 PSI_memory_key key_memory_ST_SCHEMA_TABLE;
 PSI_memory_key key_memory_Slave_applier_json_diff_vector;
@@ -99,7 +101,6 @@ PSI_memory_key key_memory_acl_memex;
 PSI_memory_key key_memory_acl_cache;
 PSI_memory_key key_memory_acl_map_cache;
 PSI_memory_key key_memory_binlog_cache_mngr;
-PSI_memory_key key_memory_binlog_pos;
 PSI_memory_key key_memory_binlog_recover_exec;
 PSI_memory_key key_memory_binlog_statement_buffer;
 PSI_memory_key key_memory_bison_stack;
@@ -282,7 +283,7 @@ static PSI_memory_info all_server_memory[] = {
      PSI_DOCUMENT_ME},
     {&key_memory_Owned_gtids_sidno_to_hash, "Owned_gtids::sidno_to_hash", 0, 0,
      PSI_DOCUMENT_ME},
-    {&key_memory_Sid_map_Node, "Sid_map::Node", 0, 0, PSI_DOCUMENT_ME},
+    {&key_memory_tsid_map_Node, "Tsid_map::Node", 0, 0, PSI_DOCUMENT_ME},
     {&key_memory_Gtid_state_group_commit_sidno,
      "Gtid_state::group_commit_sidno_locks", 0, 0, PSI_DOCUMENT_ME},
     {&key_memory_Mutex_cond_array_Mutex_cond, "Mutex_cond_array::Mutex_cond", 0,
@@ -297,7 +298,6 @@ static PSI_memory_info all_server_memory[] = {
     {&key_memory_rpl_replica_check_temp_dir, "rpl_replica::check_temp_dir", 0,
      0, PSI_DOCUMENT_ME},
     {&key_memory_REPLICA_INFO, "REPLICA_INFO", 0, 0, PSI_DOCUMENT_ME},
-    {&key_memory_binlog_pos, "binlog_pos", 0, 0, PSI_DOCUMENT_ME},
     {&key_memory_HASH_ROW_ENTRY, "HASH_ROW_ENTRY", 0, 0, PSI_DOCUMENT_ME},
     {&key_memory_binlog_statement_buffer, "binlog_statement_buffer", 0, 0,
      PSI_DOCUMENT_ME},
@@ -397,6 +397,8 @@ static PSI_memory_info all_server_memory[] = {
      PSI_DOCUMENT_ME},
     {&key_memory_recovery, "Binlog_recovery::recover", 0, 0, PSI_DOCUMENT_ME},
     {&key_memory_show_binlog_events, "show_binlog_events", 0, 0,
+     PSI_DOCUMENT_ME},
+    {&key_memory_relaylog_recovery, "Relay_log_sanitizer::analyze_logs", 0, 0,
      PSI_DOCUMENT_ME}};
 
 void register_server_memory_keys() {
